pub struct BufMut { /* private fields */ }Implementations
Sourceimpl BufMut
impl BufMut
pub const fn new(from: Vec<u8>) -> Self
Sourcepub fn remaining(&self) -> usize
pub fn remaining(&self) -> usize
Remaining for write from the write position to the end of the buffer
Sourcepub fn as_mut_remaining(&mut self) -> &mut [u8] ⓘ
pub fn as_mut_remaining(&mut self) -> &mut [u8] ⓘ
Returns a slice of the buffer with space available for writing, that is from the write position to the end of the buffer
pub fn clear(&mut self)
pub const fn available(&self) -> usize
pub const fn available_read(&self) -> usize
pub fn seek_write(&mut self, pos: SeekFrom) -> Result<u64>
pub fn seek_available(&mut self, pos: SeekFrom) -> Result<u64>
pub const fn pos_read(&self) -> usize
pub const fn pos_write(&self) -> usize
pub fn capacity(&self) -> usize
Sourcepub fn as_ref_read_available(&self) -> &[u8] ⓘ
pub fn as_ref_read_available(&self) -> &[u8] ⓘ
Returns a slice of the buffer with content available for reading